==> Moony_0.5.0.tar.gz: Moony/lib/moony/core/Moony_Controller.php <==
<?php
/**
 * ȥ饯饹Ǥ
 * εưԤޤ
 * 
 * @access public
 * @author YAMAOKA Hiroyuki
 * @package moony.core
 */
class Moony_Controller {

	/** @var string ̾ */
	var $_action_name;

	/** @var array Υѥ᡼ʬ */
	var $_parameters;

	/**
	 * 󥹥ȥ饯Ǥ
	 * 
	 * @access public
	 */
	function Moony_Controller() {
	}

	/**
	 * ꡼ʸβϤԤ
	 * ̾ꤷޤ
	 * ̾ꤵƤʤ硢
	 * config.phpꤵ줿ǥեȥ̾Ѥޤ
	 * 
	 * @access public
	 * @param string $query_string ꡼ʸ
	 */
	function init($query_string) {

		$settings = split('/', $query_string);

		// ̾ȤΩ
		$this->_action_name = '';
		for ($i = 0; $i < MOONY_EVAL_AS_ACTION_SETTING; $i++) {
			if (isset($settings[$i])) {
				$this->_action_name .= ucfirst($settings[$i]);
			}
		}

		// ꤵƤʤ硢ǥեȥ
		if (strlen($this->_action_name) == 0) {
			$this->_action_name = MOONY_DEFAULT_ACTION_NAME;
		}

		// ̾ȤƻѤʤѥ᡼
		$this->_parameters = array_slice($settings, MOONY_EVAL_AS_ACTION_SETTING);
	}

	/**
	 * ºݤνԤޤưޤ
	 * ޤꤵ줿б륯饹¸ߤʤϡ
	 * ̵˥̾ɳդƥץ졼Ȥɽޤ
	 * 
	 * @access public
	 */
	function process() {

		$class_name = $this->_action_name . 'Action';
		$class_path = MOONY_ACTION_DIR . '/' . $class_name . '.php';

		// 󥯥饹¸ߥå
		if (!file_exists($class_path)) {
			$view =& new Moony_View();
			$view->init($this->_action_name);
			$view->forward();
			exit;
		}

		include_once $class_path;
		$action =& new $class_name;

		$request =& new Moony_Request();
		$request->store();

		$view =& new Moony_View();
		$view->init($this->_action_name);

		$session =& new Moony_Session();
		$session->start();

		$action->init($this->_parameters);
		$action->execute($request, $session, $view);
	}
}
?>

==> Moony_0.5.1.tar.gz: Moony/lib/moony/core/Moony_Controller.php <==
<?php
/**
 * ȥ饯饹Ǥ
 * εưԤޤ
 * 
 * @access public
 * @author YAMAOKA Hiroyuki
 * @package moony.core
 */
class Moony_Controller {

	/** @var string ̾ */
	var $_action_name;

	/** @var array Υѥ᡼ʬ */
	var $_parameters;

	/**
	 * 󥹥ȥ饯Ǥ
	 * 
	 * @access public
	 */
	function Moony_Controller() {
	}

	/**
	 * ꡼ʸβϤԤ
	 * ̾ꤷޤ
	 * ̾ꤵƤʤ硢
	 * config.phpꤵ줿ǥեȥ̾Ѥޤ
	 * 
	 * @access public
	 * @param string $query_string ꡼ʸ
	 */
	function init($query_string) {

		$settings = split('/', $query_string);

		// ̾ȤΩ
		$this->_action_name = '';
		for ($i = 0; $i < MOONY_EVAL_AS_ACTION_SETTING; $i++) {
			if (isset($settings[$i])) {
				$this->_action_name .= ucfirst($settings[$i]);
			}
		}

		// ꤵƤʤ硢ǥեȥ
		if (strlen($this->_action_name) == 0) {
			$this->_action_name = MOONY_DEFAULT_ACTION_NAME;
		}

		// ̾ȤƻѤʤѥ᡼
		$this->_parameters = array_slice($settings, MOONY_EVAL_AS_ACTION_SETTING);
	}

	/**
	 * ºݤνԤޤưޤ
	 * ޤꤵ줿б륯饹¸ߤʤϡ
	 * ̵˥̾ɳդƥץ졼Ȥɽޤ
	 * 
	 * @access public
	 */
	function process() {

		$class_name = $this->_action_name . 'Action';
		$class_path = MOONY_ACTION_DIR . '/' . $class_name . '.' . MOONY_ACTION_EXT;

		// 󥯥饹¸ߥå
		if (!file_exists($class_path)) {
			$view =& new Moony_View();
			$view->init($this->_action_name);
			$view->forward();
			exit;
		}

		include_once $class_path;
		$action =& new $class_name;

		$request =& new Moony_Request();
		$request->store();

		$view =& new Moony_View();
		$view->init($this->_action_name);

		$session =& new Moony_Session();
		$session->start();

		$action->init($this->_parameters);
		$action->execute($request, $session, $view);
	}
}
?>
